[![PyPI version](https://badge.fury.io/py/graphe.svg)](https://badge.fury.io/py/graphe)

# graphe
A pypi package with a collection of graph algorithms and visualisations.

![](https://raw.githubusercontent.com/mortenjc/pygraph/main/docssource/images/long.png)


# Documentation

[ReadTheDocs](https://graphe.readthedocs.io/)
